import { ImperativeError, SecureCredential } from "@zowe/imperative";
import * as keytar from "keytar";
declare const _default: {
    new (service: string, displayName: string): {
        /**
         * Reference to the lazily loaded keytar module.
         *
         * @private
         */
        keytar: typeof keytar;
        /**
         * This variable indicates which service should be used when loading secure properties in the case of a conflict
         * lts-incremental --> @brightside/core
         * latest -----------> @zowe/cli
         */
        PLUGIN_CREDENTIAL_PREFERENCE: string;
        /**
         * Errors that occurred while loading keytar will be stored in here.
         *
         * Every method of this class should call the {@link checkForKeytar} method before proceeding. It
         * is this method that will check for keytar and throw this error if it was detected that keytar
         * wasn't loaded.
         *
         * @private
         */
        loadError: ImperativeError;
        /**
         * Combined list of services that the plugin will go through
         */
        allServices: string[];
        /**
         * Called by {@link CredentialManagerFactory.initialize} before the freeze of the object. This
         * gives us a chance to load keytar into the class before we are locked down. If a load failure
         * occurs, we will store the error and throw it once a method of this class tries to execute. This
         * prevents a missing keytar module from stopping all operation of the cli.
         *
         * In the future, we could go even further to have keytar load into a sub-object of this class so
         * that the load doesn't hold up the main class execution.
         *
         * @returns {Promise<void>} A promise that the function has completed.
         */
        initialize(): Promise<void>;
        /**
         * Calls the keytar deletePassword service with {@link DefaultCredentialManager#service} and the
         * account passed to the function by Imperative.
         *
         * @param {string} account The account for which to delete the password
         *
         * @returns {Promise<void>} A promise that the function has completed.
         *
         * @throws {@link ImperativeError} if keytar is not defined.
         */
        deleteCredentials(account: string): Promise<void>;
        /**
         * Calls the keytar getPassword service with {@link DefaultCredentialManager#service} and the
         * account passed to the function by Imperative.
         *
         * @param {string} account The account for which to get credentials
         * @returns {Promise<SecureCredential>} A promise containing the credentials stored in keytar.
         *
         * @throws {@link ImperativeError} if keytar is not defined.
         * @throws {@link ImperativeError} when keytar.getPassword returns null or undefined.
         */
        loadCredentials(account: string, optional?: boolean): Promise<SecureCredential>;
        /**
         * Calls the keytar setPassword service with {@link DefaultCredentialManager#service} and the
         * account and credentials passed to the function by Imperative.
         *
         * @param {string} account The account to set credentials
         * @param {SecureCredential} credentials The credentials to store
         *
         * @returns {Promise<void>} A promise that the function has completed.
         *
         * @throws {@link ImperativeError} if keytar is not defined.
         */
        saveCredentials(account: string, credentials: SecureCredential): Promise<void>;
        /**
         * This function is called before the {@link deletePassword}, {@link getPassword}, and
         * {@link setPassword} functions. It will check if keytar is not null and will throw an error
         * if it is.
         *
         * The error thrown will be the contents of {@link loadError} or a new {@link ImperativeError}.
         * The former error will be the most common one as we expect failures during the load since keytar
         * is optional. The latter error will indicate that some unknown condition has happened so we will
         * create a new ImperativeError with the report suppressed. The report is suppressed because it
         * may be possible that a detailed report could capture a username and password, which would
         * probably be a bad thing.
         *
         * @private
         *
         * @throws {@link ImperativeError} when keytar is null or undefined.
         */
        checkForKeytar(): void;
        deleteCredentialsHelper(account: string, skipPluginService?: boolean): Promise<boolean>;
        getMissingEntryMessage(account: string): string;
        readonly service: string;
        displayName: any;
        readonly name: string;
        delete(account: string): Promise<void>;
        load(account: string, optional?: boolean): Promise<string>;
        save(account: string, secureValue: string): Promise<void>;
    };
};
/**
 * Keytar - Securely store user credentials in the system keychain
 *
 * @export
 * @class KeytarCredentialManager
 */
export = _default;
